@@ -1,5 +1,6 @@
 import inspect
 import json
+import os
 
 import pkg_resources
 
@@ -10,12 +11,7 @@ from connect.eaas.core.constants import (
 )
 
 
-class Extension:
-    def __init__(self, client, logger, config):
-        self.client = client
-        self.logger = logger
-        self.config = config
-
+class ExtensionBase:
     @classmethod
     def get_descriptor(cls):  # pragma: no cover
         return json.load(
@@ -25,6 +21,19 @@ class Extension:
             ),
         )
 
+    @classmethod
+    def get_variables(cls):
+        return getattr(cls, VARIABLES_INFO_ATTR_NAME, [])
+
+
+class Extension(ExtensionBase):
+    def __init__(self, client, logger, config, installation_client=None, installation=None):
+        self.client = client
+        self.logger = logger
+        self.config = config
+        self.installation_client = installation_client
+        self.installation = installation
+
     @classmethod
     def get_events(cls):
         return cls._get_methods_info(EVENT_INFO_ATTR_NAME)
@@ -33,10 +42,6 @@ class Extension:
     def get_schedulables(cls):
         return cls._get_methods_info(SCHEDULABLE_INFO_ATTR_NAME)
 
-    @classmethod
-    def get_variables(cls):
-        return getattr(cls, VARIABLES_INFO_ATTR_NAME, [])
-
     @classmethod
     def _get_methods_info(cls, attr_name):
         info = []
@@ -47,3 +52,18 @@ class Extension:
             if hasattr(value, attr_name):
                 info.append(getattr(value, attr_name))
         return info
+
+
+class UIExtension(ExtensionBase):
+
+    @classmethod
+    def get_static_root(cls):
+        static_root = os.path.abspath(
+            os.path.join(
+                os.path.dirname(inspect.getfile(cls)),
+                'static_root',
+            ),
+        )
+        if os.path.exists(static_root) and os.path.isdir(static_root):
+            return static_root
+        return None
